# Cisco Proprietary License

These schema files are part of VIRL 2 / Cisco Modeling Labs (CML)

Copyright (c) 2019-2026, Cisco Systems, Inc.

All rights reserved.

## Notice

The Pydantic schema files and other support files located under `src/cml_mcp/cml/` are derived from Cisco Modeling Labs and are subject to Cisco's proprietary license terms. These files are included in this project for the purpose of providing proper type definitions and API compatibility with CML servers.

The rest of this project (excluding these schema files) is licensed under the BSD 2-Clause "Simplified" License. See the [LICENSE](LICENSE) file for details.
